@@ -72,7 +72,7 @@ class Tapestry(Tool):  # pylint: disable=too-many-instance-attributes
 			Mount('/config', self.config_path, type='bind', read_only=True)
 		)
 
-		self.port = self.config['cluster'].get('port', self.port)
+		self.port = self.config['docker'].get('port', self.port)
 		docker.services.create(
 			'evilkermit/substrate_tapestry:latest',
 			'./server',
@@ -81,7 +81,7 @@ class Tapestry(Tool):  # pylint: disable=too-many-instance-attributes
 			env=['APP_DIR=/app'],
 			mode=ServiceMode(
 				mode='replicated',
-				replicas=self.config['cluster'].get('replicas', 1)
+				replicas=self.config['docker'].get('replicas', 1)
 			),
 			mounts=mounts,
 			name='tapestry',
@@ -91,18 +91,14 @@ class Tapestry(Tool):  # pylint: disable=too-many-instance-attributes
 	def upload_to_s3(self):
 		super().upload_to_s3()
 
-		subprocess.run([
-			'aws',
-			's3',
-			'sync',
-			self.app_path,
-			f's3://{self.config["aws"]["bucket"]}/app'
-		], check=True)
+		subprocess.run(
+			f'aws s3 sync {self.app_path} s3://{self.config["aws"]["bucket"]}/app',
+			check=True,
+			shell=True
+		)
 
-		subprocess.run([
-			'aws',
-			's3',
-			'sync',
-			self.config_path,
-			f's3://{self.config["aws"]["bucket"]}/config'
-		], check=True)
+		subprocess.run(
+			f'aws s3 sync {self.config_path} s3://{self.config["aws"]["bucket"]}/config',  # noqa: E501
+			check=True,
+			shell=True
+		)
